@@ -42,7 +42,7 @@ if ($page == 'admins'
 			'traffic_used' => $lng['customer']['traffic'] . ' (' . $lng['panel']['used'] . ')',
 			'deactivated' => $lng['admin']['deactivated']
 		);
-		$paging = new paging($userinfo, TABLE_PANEL_ADMINS, $fields, $settings['panel']['paging'], $settings['panel']['natsorting']);
+		$paging = new paging($userinfo, TABLE_PANEL_ADMINS, $fields);
 		$admins = '';
 		$result_stmt = Database::query("SELECT * FROM `" . TABLE_PANEL_ADMINS . "` " . $paging->getSqlWhere(false) . " " . $paging->getSqlOrderBy() . " " . $paging->getSqlLimit());
 		$numrows_admins = Database::num_rows();
@@ -54,19 +54,21 @@ if ($page == 'admins'
 		$i = 0;
 		$count = 0;
 
+		$dec_places = Settings::Get('panel.decimal_places');
+
 		while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 
 			if ($paging->checkDisplay($i)) {
 
-				$row['traffic_used'] = round($row['traffic_used'] / (1024 * 1024), $settings['panel']['decimal_places']);
-				$row['traffic'] = round($row['traffic'] / (1024 * 1024), $settings['panel']['decimal_places']);
-				$row['diskspace_used'] = round($row['diskspace_used'] / 1024, $settings['panel']['decimal_places']);
-				$row['diskspace'] = round($row['diskspace'] / 1024, $settings['panel']['decimal_places']);
+				$row['traffic_used'] = round($row['traffic_used'] / (1024 * 1024), $dec_places);
+				$row['traffic'] = round($row['traffic'] / (1024 * 1024), $dec_places);
+				$row['diskspace_used'] = round($row['diskspace_used'] / 1024, $dec_places);
+				$row['diskspace'] = round($row['diskspace'] / 1024, $dec_places);
 
 				// percent-values for progressbar
 				// For Disk usage
 				if ($row['diskspace'] > 0) {
-					$disk_percent = round(($row['diskspace_used']*100)/$row['diskspace'], 2);
+					$disk_percent = round(($row['diskspace_used']*100)/$row['diskspace'], 0);
 					$disk_doublepercent = round($disk_percent*2, 2);
 				} else {
 					$disk_percent = 0;
@@ -74,15 +76,26 @@ if ($page == 'admins'
 				}
 				// For Traffic usage
 				if ($row['traffic'] > 0) {
-					$traffic_percent = round(($row['traffic_used']*100)/$row['traffic'], 2);
+					$traffic_percent = round(($row['traffic_used']*100)/$row['traffic'], 0);
 					$traffic_doublepercent = round($traffic_percent*2, 2);
 				} else {
 					$traffic_percent = 0;
 					$traffic_doublepercent = 0;
 				}
 
-				$row = str_replace_array('-1', 'UL', $row, 'customers domains diskspace traffic mysqls emails email_accounts email_forwarders email_quota email_autoresponder ftps subdomains tickets');
+				// fix progress-bars if value is >100%
+				if ($disk_percent > 100) {
+					$disk_percent = 100;
+				}
+				if ($traffic_percent > 100) {
+					$traffic_percent = 100;
+				}
+
+				$row = str_replace_array('-1', 'UL', $row, 'customers domains diskspace traffic mysqls emails email_accounts email_forwarders email_quota ftps subdomains tickets');
 				$row = htmlentities_array($row);
+
+				$row['custom_notes'] = ($row['custom_notes'] != '') ? nl2br($row['custom_notes']) : '';
+
 				eval("\$admins.=\"" . getTemplate("admins/admins_admin") . "\";");
 				$count++;
 			}
@@ -188,6 +201,9 @@ if ($page == 'admins'
 			$name = validate($_POST['name'], 'name');
 			$email = $idna_convert->encode(validate($_POST['email'], 'email'));
 
+			$custom_notes = validate(str_replace("\r\n", "\n", $_POST['custom_notes']), 'custom_notes', '/^[^\0]*$/');
+			$custom_notes_show = intval_ressource($_POST['custom_notes_show']);
+
 			$loginname = validate($_POST['loginname'], 'loginname');
 			$password = validate($_POST['admin_password'], 'password');
 			$password = validatePassword($password);
@@ -195,64 +211,54 @@ if ($page == 'admins'
 
 			$customers = intval_ressource($_POST['customers']);
 			if (isset($_POST['customers_ul'])) {
-				$customers = - 1;
+				$customers = -1;
 			}
 
 			$domains = intval_ressource($_POST['domains']);
 			if (isset($_POST['domains_ul'])) {
-				$domains = - 1;
+				$domains = -1;
 			}
 
 			$subdomains = intval_ressource($_POST['subdomains']);
 			if (isset($_POST['subdomains_ul'])) {
-				$subdomains = - 1;
+				$subdomains = -1;
 			}
 
 			$emails = intval_ressource($_POST['emails']);
 			if (isset($_POST['emails_ul'])) {
-				$emails = - 1;
+				$emails = -1;
 			}
 
 			$email_accounts = intval_ressource($_POST['email_accounts']);
 			if (isset($_POST['email_accounts_ul'])) {
-				$email_accounts = - 1;
+				$email_accounts = -1;
 			}
 
 			$email_forwarders = intval_ressource($_POST['email_forwarders']);
 			if (isset($_POST['email_forwarders_ul'])) {
-				$email_forwarders = - 1;
+				$email_forwarders = -1;
 			}
 
-			if ($settings['system']['mail_quota_enabled'] == '1') {
+			if (Settings::Get('system.mail_quota_enabled') == '1') {
 
 				$email_quota = validate($_POST['email_quota'], 'email_quota', '/^\d+$/', 'vmailquotawrong', array('0', ''));
 				if (isset($_POST['email_quota_ul'])) {
-					$email_quota = - 1;
+					$email_quota = -1;
 				}
 			} else {
-				$email_quota = - 1;
-			}
-
-			if ($settings['autoresponder']['autoresponder_active'] == '1') {
-
-				$email_autoresponder = intval_ressource($_POST['email_autoresponder']);
-				if (isset($_POST['email_autoresponder_ul'])) {
-					$email_autoresponder = - 1;
-				}
-			} else {
-				$email_autoresponder = 0;
+				$email_quota = -1;
 			}
 
 			$ftps = intval_ressource($_POST['ftps']);
 			if (isset($_POST['ftps_ul'])) {
-				$ftps = - 1;
+				$ftps = -1;
 			}
 
-			if ($settings['ticket']['enabled'] == 1) {
+			if (Settings::Get('ticket.enabled') == 1) {
 
 				$tickets = intval_ressource($_POST['tickets']);
 				if (isset($_POST['tickets_ul'])) {
-					$tickets = - 1;
+					$tickets = -1;
 				}
 			} else {
 				$tickets = 0;
@@ -260,20 +266,7 @@ if ($page == 'admins'
 
 			$mysqls = intval_ressource($_POST['mysqls']);
 			if (isset($_POST['mysqls_ul'])) {
-				$mysqls = - 1;
-			}
-
-			if ($settings['aps']['aps_active'] == '1') {
-
-				$number_of_aps_packages = intval_ressource($_POST['number_of_aps_packages']);
-				if (isset($_POST['number_of_aps_packages_ul'])) {
-					$number_of_aps_packages = - 1;
-				}
-				$can_manage_aps_packages = isset($_POST['can_manage_aps_packages']) ? 1 : 0;
-
-			} else {
-				$number_of_aps_packages = 0;
-				$can_manage_aps_packages = 0;
+				$mysqls = -1;
 			}
 
 			$customers_see_all = 0;
@@ -298,12 +291,12 @@ if ($page == 'admins'
 
 			$diskspace = intval_ressource($_POST['diskspace']);
 			if (isset($_POST['diskspace_ul'])) {
-				$diskspace = - 1;
+				$diskspace = -1;
 			}
 
 			$traffic = doubleval_ressource($_POST['traffic']);
 			if (isset($_POST['traffic_ul'])) {
-				$traffic = - 1;
+				$traffic = -1;
 			}
 
 			$tickets_see_all = 0;
@@ -335,8 +328,8 @@ if ($page == 'admins'
 				standard_error('loginnameexists', $loginname);
 			}
 			// Accounts which match systemaccounts are not allowed, filtering them
-			elseif (preg_match('/^' . preg_quote($settings['customer']['accountprefix'], '/') . '([0-9]+)/', $loginname)) {
-				standard_error('loginnameissystemaccount', $settings['customer']['accountprefix']);
+			elseif (preg_match('/^' . preg_quote(Settings::Get('customer.accountprefix'), '/') . '([0-9]+)/', $loginname)) {
+				standard_error('loginnameissystemaccount', Settings::Get('customer.accountprefix'));
 			}
 			elseif (!validateUsername($loginname)) {
 				standard_error('loginnameiswrong', $loginname);
@@ -375,11 +368,11 @@ if ($page == 'admins'
 					$tickets_see_all  = '0';
 				}
 
-				$_theme = $settings['panel']['default_theme'];
+				$_theme = Settings::Get('panel.default_theme');
 
 				$ins_data = array(
 					'loginname' => $loginname,
-					'password' => md5($password),
+					'password' => makeCryptPassword($password),
 					'name' => $name,
 					'email' => $email,
 					'lang' => $def_language,
@@ -401,10 +394,9 @@ if ($page == 'admins'
 					'tickets_see_all' => $tickets_see_all,
 					'mysqls' => $mysqls,
 					'ip' => $ipaddress,
-					'can_manage_aps_packages' => $can_manage_aps_packages,
-					'aps_packages' => $number_of_aps_packages,
-					'autoresponder' => $email_autoresponder,
-					'theme' => $_theme
+					'theme' => $_theme,
+					'custom_notes' => $custom_notes,
+					'custom_notes_show' => $custom_notes_show
 				);
 
 				$ins_stmt = Database::prepare("
@@ -432,10 +424,9 @@ if ($page == 'admins'
 					`tickets_see_all` = :tickets_see_all,
 					`mysqls` = :mysqls,
 					`ip` = :ip,
-					`can_manage_aps_packages` = :can_manage_aps_packages,
-					`aps_packages` = :aps_packages,
-					`email_autoresponder` = :autoresponder,
-					`theme` = :theme
+					`theme` = :theme,
+					`custom_notes` = :custom_notes,
+					`custom_notes_show` = :custom_notes_show
 				");
 				Database::pexecute($ins_stmt, $ins_data);
 
@@ -476,11 +467,9 @@ if ($page == 'admins'
 			$email_accounts_ul = makecheckbox('email_accounts_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 			$email_forwarders_ul = makecheckbox('email_forwarders_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 			$email_quota_ul = makecheckbox('email_quota_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
-			$email_autoresponder_ul = makecheckbox('email_autoresponder_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 			$ftps_ul = makecheckbox('ftps_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 			$tickets_ul = makecheckbox('tickets_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 			$mysqls_ul = makecheckbox('mysqls_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
-			$number_of_aps_packages_ul = makecheckbox('number_of_aps_packages_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 
 			$admin_add_data = include_once dirname(__FILE__).'/lib/formfields/admin/admin/formfield.admin_add.php';
 			$admin_add_form = htmlform::genHTMLForm($admin_add_data);
@@ -508,6 +497,9 @@ if ($page == 'admins'
 				$name = validate($_POST['name'], 'name');
 				$email = $idna_convert->encode(validate($_POST['email'], 'email'));
 
+				$custom_notes = validate(str_replace("\r\n", "\n", $_POST['custom_notes']), 'custom_notes', '/^[^\0]*$/');
+				$custom_notes_show = intval_ressource($_POST['custom_notes_show']);
+
 				if ($result['adminid'] == $userinfo['userid']) {
 
 					$password = '';
@@ -520,7 +512,6 @@ if ($page == 'admins'
 					$email_accounts = $result['email_accounts'];
 					$email_forwarders = $result['email_forwarders'];
 					$email_quota = $result['email_quota'];
-					$email_autoresponder = $result['email_autoresponder'];
 					$ftps = $result['ftps'];
 					$tickets = $result['tickets'];
 					$mysqls = $result['mysqls'];
@@ -532,8 +523,6 @@ if ($page == 'admins'
 					$diskspace = $result['diskspace'];
 					$traffic = $result['traffic'];
 					$ipaddress = $result['ip'];
-					$can_manage_aps_packages = $result['can_manage_aps_packages'];
-					$number_of_aps_packages = $result['aps_packages'];
 
 				} else {
 
@@ -571,7 +560,7 @@ if ($page == 'admins'
 						$email_forwarders = -1;
 					}
 
-					if ($settings['system']['mail_quota_enabled'] == '1') {
+					if (Settings::Get('system.mail_quota_enabled') == '1') {
 						$email_quota = validate($_POST['email_quota'], 'email_quota', '/^\d+$/', 'vmailquotawrong', array('0', ''));
 						if (isset($_POST['email_quota_ul'])) {
 							$email_quota = -1;
@@ -580,21 +569,12 @@ if ($page == 'admins'
 						$email_quota = -1;
 					}
 
-					if ($settings['autoresponder']['autoresponder_active'] == '1') {
-						$email_autoresponder = intval_ressource($_POST['email_autoresponder']);
-						if (isset($_POST['email_autoresponder_ul'])) {
-							$email_autoresponder = -1;
-						}
-					} else {
-						$email_autoresponder = 0;
-					}
-
 					$ftps = intval_ressource($_POST['ftps']);
 					if (isset($_POST['ftps_ul'])) {
 						$ftps = -1;
 					}
-					
-					if ($settings['ticket']['enabled'] == 1) {
+
+					if (Settings::Get('ticket.enabled') == 1) {
 						$tickets = intval_ressource($_POST['tickets']);
 						if (isset($_POST['tickets_ul'])) {
 							$tickets = -1;
@@ -605,17 +585,7 @@ if ($page == 'admins'
 
 					$mysqls = intval_ressource($_POST['mysqls']);
 					if (isset($_POST['mysqls_ul'])) {
-						$mysqls = - 1;
-					}
-
-					if ($settings['aps']['aps_active'] == '1') {
-						$number_of_aps_packages = intval_ressource($_POST['number_of_aps_packages']);
-						if (isset($_POST['number_of_aps_packages_ul'])) {
-							$number_of_aps_packages = -1;
-						}
-						$can_manage_aps_packages = isset($_POST['can_manage_aps_packages']) ? 1 : 0;
-					} else {
-						$number_of_aps_packages = 0;
+						$mysqls = -1;
 					}
 
 					$customers_see_all = 0;
@@ -667,7 +637,7 @@ if ($page == 'admins'
 				} else {
 					if ($password != '') {
 						$password = validatePassword($password);
-						$password = md5($password);
+						$password = makeCryptPassword($password);
 					} else {
 						$password = $result['password'];
 					}
@@ -699,10 +669,10 @@ if ($page == 'admins'
 					// check if a resource was set to something lower
 					// than actually used by the admin/reseller
 					$res_warning = "";
-					if ($customers != $result['customers'] && $customers < $result['customers_used']) {
+					if ($customers != $result['customers'] && $customers != -1 && $customers < $result['customers_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'customers');
 					}
-					if ($domains != $result['domains'] && $domains < $result['domains_used']) {
+					if ($domains != $result['domains'] && $domains != -1 && $domains < $result['domains_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'domains');
 					}
 					if ($diskspace != $result['diskspace'] && ($diskspace / 1024) != -1 && $diskspace < $result['diskspace_used']) {
@@ -711,33 +681,27 @@ if ($page == 'admins'
 					if ($traffic != $result['traffic'] && ($traffic / 1024 / 1024) != -1 && $traffic < $result['traffic_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'traffic');
 					}
-					if ($emails != $result['emails'] && $emails < $result['emails_used']) {
+					if ($emails != $result['emails'] && $emails != -1 && $emails < $result['emails_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'emails');
 					}
-					if ($email_accounts != $result['email_accounts'] && $email_accounts < $result['email_accounts_used']) {
+					if ($email_accounts != $result['email_accounts'] && $email_accounts != -1 && $email_accounts < $result['email_accounts_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'email accounts');
 					}
-					if ($email_forwarders != $result['email_forwarders'] && $email_forwarders < $result['email_forwarders_used']) {
+					if ($email_forwarders != $result['email_forwarders'] && $email_forwarders != -1 && $email_forwarders < $result['email_forwarders_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'email forwarders');
 					}
-					if ($email_quota != $result['email_quota'] && $email_quota < $result['email_quota_used']) {
+					if ($email_quota != $result['email_quota'] && $email_quota != -1 && $email_quota < $result['email_quota_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'email quota');
 					}
-					if ($email_autoresponder != $result['email_autoresponder'] && $email_autoresponder < $result['email_autoresponder_used']) {
-						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'email autoresponder');
-					}
-					if ($ftps != $result['ftps'] && $ftps < $result['ftps_used']) {
+					if ($ftps != $result['ftps'] && $ftps != -1 && $ftps < $result['ftps_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'ftps');
 					}
-					if ($tickets != $result['tickets'] && $tickets < $result['tickets_used']) {
+					if ($tickets != $result['tickets'] && $tickets != -1 && $tickets < $result['tickets_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'tickets');
 					}
-					if ($mysqls != $result['mysqls'] && $mysqls < $result['mysqls_used']) {
+					if ($mysqls != $result['mysqls'] && $mysqls != -1 && $mysqls < $result['mysqls_used']) {
 						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'mysqls');
 					}
-					if ($number_of_aps_packages != $result['aps_packages'] && $number_of_aps_packages < $result['aps_packages_used']) {
-						$res_warning .= sprintf($lng['error']['setlessthanalreadyused'], 'aps packages');
-					}
 
 					if ($res_warning != "") {
 						$link = '';
@@ -770,9 +734,8 @@ if ($page == 'admins'
 						'mysqls' => $mysqls,
 						'ip' => $ipaddress,
 						'deactivated' => $deactivated,
-						'can_manage_aps_packages' => $can_manage_aps_packages,
-						'aps_packages' => $number_of_aps_packages,
-						'autoresponder' => $email_autoresponder,
+						'custom_notes' => $custom_notes,
+						'custom_notes_show' => $custom_notes_show,
 						'adminid' => $id
 					);
 
@@ -801,9 +764,8 @@ if ($page == 'admins'
 						`mysqls` = :mysqls,
 						`ip` = :ip,
 						`deactivated` = :deactivated,
-						`can_manage_aps_packages` = :can_manage_aps_packages,
-						`aps_packages` = :aps_packages,
-						`email_autoresponder` = :autoresponder
+						`custom_notes` = :custom_notes,
+						`custom_notes_show` = :custom_notes_show
 						WHERE `adminid` = :adminid
 					");
 					Database::pexecute($upd_stmt, $upd_data);
@@ -814,8 +776,9 @@ if ($page == 'admins'
 
 			} else {
 
-				$result['traffic'] = round($result['traffic'] / (1024 * 1024), $settings['panel']['decimal_places']);
-				$result['diskspace'] = round($result['diskspace'] / 1024, $settings['panel']['decimal_places']);
+				$dec_places = Settings::Get('panel.decimal_places');
+				$result['traffic'] = round($result['traffic'] / (1024 * 1024), $dec_places);
+				$result['diskspace'] = round($result['diskspace'] / 1024, $dec_places);
 				$result['email'] = $idna_convert->decode($result['email']);
 
 				$customers_ul = makecheckbox('customers_ul', $lng['customer']['unlimited'], '-1', false, $result['customers'], true, true);
@@ -863,11 +826,6 @@ if ($page == 'admins'
 					$result['email_quota'] = '';
 				}
 
-				$email_autoresponder_ul = makecheckbox('email_autoresponder_ul', $lng['customer']['unlimited'], '-1', false, $result['email_autoresponder'], true, true);
-				if ($result['email_autoresponder'] == '-1') {
-					$result['email_autoresponder'] = '';
-				}
-
 				$ftps_ul = makecheckbox('ftps_ul', $lng['customer']['unlimited'], '-1', false, $result['ftps'], true, true);
 				if ($result['ftps'] == '-1') {
 					$result['ftps'] = '';
@@ -883,11 +841,6 @@ if ($page == 'admins'
 					$result['mysqls'] = '';
 				}
 
-				$number_of_aps_packages_ul = makecheckbox('number_of_aps_packages_ul', $lng['customer']['unlimited'], '-1', false, $result['aps_packages'], true, true);
-				if ($result['aps_packages'] == '-1') {
-					$result['aps_packages'] = '';
-				}
-
 				$language_options = '';
 				while (list($language_file, $language_name) = each($languages)) {
 					$language_options.= makeoption($language_name, $language_file, $result['def_language'], true);
