@@ -16,6 +16,18 @@
  *
  */
 
+// Load the user settings
+define('FROXLOR_INSTALL_DIR', dirname(dirname(__FILE__)));
+if (!file_exists('./userdata.inc.php')) {
+	die();
+}
+require './userdata.inc.php';
+require './tables.inc.php';
+require './classes/database/class.Database.php';
+require './classes/settings/class.Settings.php';
+require './functions/validate/function.validate_ip.php';
+require './functions/validate/function.validateDomain.php';
+
 if(isset($_POST['action'])) {
 	$action = $_POST['action'];
 } elseif(isset($_GET['action'])) {
@@ -25,15 +37,16 @@ if(isset($_POST['action'])) {
 }
 
 if ($action == "newsfeed") {
-	$feed = "http://inside.froxlor.org/news/";
+	if (isset($_GET['role']) && $_GET['role'] == "customer") {
+		$feed = Settings::Get("customer.news_feed_url");
+	} else {
+		$feed = "http://inside.froxlor.org/news/";
+	}
 
 	if (function_exists("simplexml_load_file") == false) {
 		die();
 	}
 
-	// get version
-	require './tables.inc.php';
-
 	if (function_exists('curl_version')) {
 		$ch = curl_init();
 		curl_setopt($ch, CURLOPT_URL, $feed);
@@ -58,9 +71,22 @@ if ($action == "newsfeed") {
 			$title = (string)$item->title;
 			$link = (string)$item->link;
 			$date = date("Y-m-d G:i", strtotime($item->pubDate));
-			$content = preg_replace("/[\r\n]+/", "", strip_tags($item->description));
+			$content = preg_replace("/[\r\n]+/", " ", strip_tags($item->description));
+			$content = substr($content, 0, 150) . "...";
 
-			echo "<div class=\"newsitem\"><small>" . $date . "</small><br /><a href=\"" . $link . "\" target=\"_blank\"><b>" . $title . "</b><br />" . $content . "</a></div>";
+			echo "<li class=\"clearfix\">
+                <div class=\"newsfeed-body clearfix\">
+                    <div class=\"header\">
+                        <strong class=\"primary-font\"><a href=\"{$link}\" target=\"_blank\">{$title}</a></strong>
+                        <small class=\"pull-right text-muted\">
+                            <i class=\"fa fa-clock-o fa-fw\"></i> {$date}
+                        </small>
+                    </div>
+                    <p>
+                        {$content}
+                    </p>
+                </div>
+            </li>";
 		}
 	} else {
 		echo "";
