@@ -21,12 +21,6 @@
 
 class phpinterface_fpm {
 
-	/**
-	 * Settings array
-	 * @var array
-	 */
-	private $_settings = array();
-
 	/**
 	 * Domain-Data array
 	 * @var array
@@ -41,63 +35,86 @@ class phpinterface_fpm {
 
 	/**
 	 * defines what can be used for pool-config from php.ini
+	 * Mostly taken from http://php.net/manual/en/ini.list.php
+	 *
 	 * @var array
 	*/
 	private $_ini = array(
 			'php_value' => array(
-					'error_reporting',
-					'max_execution_time',
-					'include_path',
-					'upload_max_filesize',
-					'log_errors_max_len'
+				'auto_append_file',
+				'auto_prepend_file',
+				'date.timezone',
+				'default_charset',
+				'error_reporting',
+				'include_path',
+				'log_errors_max_len',
+				'mail.log',
+				'max_execution_time',
+				'session.cookie_domain',
+				'session.cookie_lifetime',
+				'session.cookie_path',
+				'session.name',
+				'session.serialize_handler',
+				'upload_max_filesize',
+				'xmlrpc_error_number',
+				'session.auto_start',
 			),
 			'php_flag' => array(
-					'short_open_tag',
-					'asp_tags',
-					'display_errors',
-					'display_startup_errors',
-					'log_errors',
-					'track_errors',
-					'html_errors',
-					'magic_quotes_gpc',
-					'magic_quotes_runtime',
-					'magic_quotes_sybase'
+				'asp_tags',
+				'display_errors',
+				'display_startup_errors',
+				'html_errors',
+				'log_errors',
+				'magic_quotes_gpc',
+				'magic_quotes_runtime',
+				'magic_quotes_sybase',
+				'mail.add_x_header',
+				'session.cookie_secure',
+				'session.use_cookies',
+				'short_open_tag',
+				'track_errors',
+				'xmlrpc_errors'
 			),
 			'php_admin_value' => array(
-					'open_basedir',
-					'precision',
-					'output_buffering',
-					'disable_functions',
-					'max_input_time',
-					'memory_limit',
-					'post_max_size',
-					'variables_order',
-					'gpc_order',
-					'date.timezone',
-					'sendmail_path',
-					'session.gc_divisor',
-					'session.gc_probability'
+				'cgi.redirect_status_env',
+				'date.timezone',
+				'disable_classes',
+				'disable_functions',
+				'error_log',
+				'gpc_order',
+				'max_input_time',
+				'memory_limit',
+				'open_basedir',
+				'output_buffering',
+				'post_max_size',
+				'precision',
+				'sendmail_path',
+				'session.gc_divisor',
+				'session.gc_probability',
+				'variables_order'
 			),
 			'php_admin_flag' => array(
-					'allow_call_time_pass_reference',
-					'allow_url_fopen',
-					'cgi.force_redirect',
-					'enable_dl',
-					'expose_php',
-					'ignore_repeated_errors',
-					'ignore_repeated_source',
-					'report_memleaks',
-					'register_argc_argv',
-					'file_uploads',
-					'allow_url_fopen'
+				'allow_call_time_pass_reference',
+				'allow_url_fopen',
+				'allow_url_include',
+				'auto_detect_line_endings',
+				'cgi.fix_pathinfo',
+				'cgi.force_redirect',
+				'enable_dl',
+				'expose_php',
+				'file_uploads',
+				'ignore_repeated_errors',
+				'ignore_repeated_source',
+				'log_errors',
+				'register_argc_argv',
+				'report_memleaks'
 			)
 	);
 
 	/**
 	 * main constructor
 	*/
-	public function __construct($settings, $domain) {
-		$this->_settings = $settings;
+	public function __construct($domain) {
 		$this->_domain = $domain;
 	}
 
@@ -111,13 +128,13 @@ class phpinterface_fpm {
 		$fh = @fopen($this->getConfigFile(), 'w');
 
 		if ($fh) {
-			$fpm_pm = $this->_settings['phpfpm']['pm'];
-			$fpm_children = (int)$this->_settings['phpfpm']['max_children'];
-			$fpm_start_servers = (int)$this->_settings['phpfpm']['start_servers'];
-			$fpm_min_spare_servers = (int)$this->_settings['phpfpm']['min_spare_servers'];
-			$fpm_max_spare_servers = (int)$this->_settings['phpfpm']['max_spare_servers'];
-			$fpm_requests = (int)$this->_settings['phpfpm']['max_requests'];
-			$fpm_process_idle_timeout = (int)$this->_settings['phpfpm']['idle_timeout'];
+			$fpm_pm = Settings::Get('phpfpm.pm');
+			$fpm_children = (int)Settings::Get('phpfpm.max_children');
+			$fpm_start_servers = (int)Settings::Get('phpfpm.start_servers');
+			$fpm_min_spare_servers = (int)Settings::Get('phpfpm.min_spare_servers');
+			$fpm_max_spare_servers = (int)Settings::Get('phpfpm.max_spare_servers');
+			$fpm_requests = (int)Settings::Get('phpfpm.max_requests');
+			$fpm_process_idle_timeout = (int)Settings::Get('phpfpm.idle_timeout');
 
 			if ($fpm_children == 0) {
 				$fpm_children = 1;
@@ -133,7 +150,8 @@ class phpinterface_fpm {
 				$fpm_config.= 'listen.owner = '.$this->_domain['loginname']."\n";
 				$fpm_config.= 'listen.group = '.$this->_domain['loginname']."\n";
 			}
-			$fpm_config.= 'listen.mode = 0666'."\n";
+			// see #1418 why this is 0660
+			$fpm_config.= 'listen.mode = 0660'."\n";
 
 			if ($this->_domain['loginname'] == 'froxlor.panel') {
 				$fpm_config.= 'user = '.$this->_domain['guid']."\n";
@@ -147,6 +165,13 @@ class phpinterface_fpm {
 			$fpm_config.= 'pm.max_children = '.$fpm_children."\n";
 
 			if ($fpm_pm == 'dynamic') {
+				// honor max_children
+				if ($fpm_children < $fpm_min_spare_servers) {
+					$fpm_min_spare_servers = $fpm_children;
+				}
+				if ($fpm_children < $fpm_max_spare_servers) {
+					$fpm_max_spare_servers = $fpm_children;
+				}
 				// failsafe, refs #955
 				if ($fpm_start_servers < $fpm_min_spare_servers) {
 					$fpm_start_servers = $fpm_min_spare_servers;
@@ -158,7 +183,6 @@ class phpinterface_fpm {
 				$fpm_config.= 'pm.min_spare_servers = '.$fpm_min_spare_servers."\n";
 				$fpm_config.= 'pm.max_spare_servers = '.$fpm_max_spare_servers."\n";
 			} elseif ($fpm_pm == 'ondemand') {
-				$fpm_config.= 'pm.start_servers = '.$fpm_start_servers."\n";
 				$fpm_config.= 'pm.process_idle_timeout = '.$fpm_process_idle_timeout."\n";
 			}
 
@@ -168,14 +192,14 @@ class phpinterface_fpm {
 			if ($phpconfig['fpm_slowlog'] == '1') {
 				$fpm_config.= 'request_terminate_timeout = ' . $phpconfig['fpm_reqterm'] . "\n";
 				$fpm_config.= 'request_slowlog_timeout = ' . $phpconfig['fpm_reqslow'] . "\n";
-				$slowlog = makeCorrectFile($this->_settings['system']['logfiles_directory'] . '/' . $this->_domain['loginname'] . '-php-slow.log');
+				$slowlog = makeCorrectFile(Settings::Get('system.logfiles_directory') . '/' . $this->_domain['loginname'] . '-php-slow.log');
 				$fpm_config.= 'slowlog = ' . $slowlog . "\n";
 				$fpm_config.= 'catch_workers_output = yes' . "\n";
 			}
 
 			$fpm_config.= ';chroot = '.makeCorrectDir($this->_domain['documentroot'])."\n";
 
-			$tmpdir = makeCorrectDir($this->_settings['phpfpm']['tmpdir'] . '/' . $this->_domain['loginname'] . '/');
+			$tmpdir = makeCorrectDir(Settings::Get('phpfpm.tmpdir') . '/' . $this->_domain['loginname'] . '/');
 			if (!is_dir($tmpdir)) {
 				$this->getTempDir();
 			}
@@ -188,12 +212,12 @@ class phpinterface_fpm {
 			if ($this->_domain['loginname'] != 'froxlor.panel') {
 				if ($this->_domain['openbasedir'] == '1') {
 					$_phpappendopenbasedir = '';
-					$_custom_openbasedir = explode(':', $this->_settings['phpfpm']['peardir']);
+					$_custom_openbasedir = explode(':', Settings::Get('phpfpm.peardir'));
 					foreach ($_custom_openbasedir as $cobd) {
 						$_phpappendopenbasedir .= appendOpenBasedirPath($cobd);
 					}
 
-					$_custom_openbasedir = explode(':', $this->_settings['system']['phpappendopenbasedir']);
+					$_custom_openbasedir = explode(':', Settings::Get('system.phpappendopenbasedir'));
 					foreach ($_custom_openbasedir as $cobd) {
 						$_phpappendopenbasedir .= appendOpenBasedirPath($cobd);
 					}
@@ -219,14 +243,14 @@ class phpinterface_fpm {
 					$openbasedir = implode(':', $clean_openbasedir);
 				}
 			}
-			$fpm_config.= 'php_admin_value[session.save_path] = ' . makeCorrectDir($this->_settings['phpfpm']['tmpdir'] . '/' . $this->_domain['loginname'] . '/') . "\n";
-			$fpm_config.= 'php_admin_value[upload_tmp_dir] = ' . makeCorrectDir($this->_settings['phpfpm']['tmpdir'] . '/' . $this->_domain['loginname'] . '/') . "\n";
+			$fpm_config.= 'php_admin_value[session.save_path] = ' . makeCorrectDir(Settings::Get('phpfpm.tmpdir') . '/' . $this->_domain['loginname'] . '/') . "\n";
+			$fpm_config.= 'php_admin_value[upload_tmp_dir] = ' . makeCorrectDir(Settings::Get('phpfpm.tmpdir') . '/' . $this->_domain['loginname'] . '/') . "\n";
 
 			$admin = $this->_getAdminData($this->_domain['adminid']);
 
 			$php_ini_variables = array(
 					'SAFE_MODE' => 'Off', // keep this for compatibility, just in case
-					'PEAR_DIR' => $this->_settings['system']['mod_fcgid_peardir'],
+					'PEAR_DIR' => Settings::Get('system.mod_fcgid_peardir'),
 					'TMP_DIR' => $this->getTempDir(),
 					'CUSTOMER_EMAIL' => $this->_domain['email'],
 					'ADMIN_EMAIL' => $admin['email'],
@@ -284,7 +308,7 @@ class phpinterface_fpm {
 	 */
 	public function getConfigFile($createifnotexists = true) {
 
-		$configdir = makeCorrectDir($this->_settings['phpfpm']['configdir']);
+		$configdir = makeCorrectDir(Settings::Get('phpfpm.configdir'));
 		$config = makeCorrectFile($configdir.'/'.$this->_domain['domain'].'.conf');
 
 		if (!is_dir($configdir) && $createifnotexists) {
@@ -303,14 +327,12 @@ class phpinterface_fpm {
 	 */
 	public function getSocketFile($createifnotexists = true) {
 
-		// see #1300 why this has changed
-		//$socketdir = makeCorrectDir('/var/run/'.$this->_settings['system']['webserver'].'/');
-		$socketdir = makeCorrectDir($this->_settings['phpfpm']['fastcgi_ipcdir']);
+		$socketdir = makeCorrectDir(Settings::Get('phpfpm.fastcgi_ipcdir'));
 		$socket = makeCorrectFile($socketdir.'/'.$this->_domain['loginname'].'-'.$this->_domain['domain'].'-php-fpm.socket');
 
 		if (!is_dir($socketdir) && $createifnotexists) {
 			safe_exec('mkdir -p '.escapeshellarg($socketdir));
-			safe_exec('chown -R '.$this->_settings['system']['httpuser'].':'.$this->_settings['system']['httpgroup'].' '.escapeshellarg($socketdir));
+			safe_exec('chown -R '.Settings::Get('system.httpuser').':'.Settings::Get('system.httpgroup').' '.escapeshellarg($socketdir));
 		}
 
 		return $socket;
@@ -325,7 +347,7 @@ class phpinterface_fpm {
 	 */
 	public function getTempDir($createifnotexists = true) {
 
-		$tmpdir = makeCorrectDir($this->_settings['phpfpm']['tmpdir'] . '/' . $this->_domain['loginname'] . '/');
+		$tmpdir = makeCorrectDir(Settings::Get('phpfpm.tmpdir') . '/' . $this->_domain['loginname'] . '/');
 
 		if (!is_dir($tmpdir) && $createifnotexists) {
 			safe_exec('mkdir -p ' . escapeshellarg($tmpdir));
@@ -346,11 +368,11 @@ class phpinterface_fpm {
 	public function getAliasConfigDir($createifnotexists = true) {
 
 		// ensure default...
-		if (!isset($this->_settings['phpfpm']['aliasconfigdir'])) {
-			$this->_settings['phpfpm']['aliasconfigdir'] = '/var/www/php-fpm';
+		if (Settings::Get('phpfpm.aliasconfigdir') == null) {
+			Settings::Set('phpfpm.aliasconfigdir', '/var/www/php-fpm');
 		}
 
-		$configdir = makeCorrectDir($this->_settings['phpfpm']['aliasconfigdir'] . '/' . $this->_domain['loginname'] . '/' . $this->_domain['domain'] . '/');
+		$configdir = makeCorrectDir(Settings::Get('phpfpm.aliasconfigdir') . '/' . $this->_domain['loginname'] . '/' . $this->_domain['domain'] . '/');
 		if (!is_dir($configdir) && $createifnotexists) {
 			safe_exec('mkdir -p ' . escapeshellarg($configdir));
 			safe_exec('chown ' . $this->_domain['guid'] . ':' . $this->_domain['guid'] . ' ' . escapeshellarg($configdir));
