@@ -18,8 +18,8 @@
  */
 
 // Try to guess user/group from settings' email UID/GID
-$vmail_user=posix_getpwuid($settings['system']['vmail_uid']);
-$vmail_group=posix_getgrgid($settings['system']['vmail_gid']);
+$vmail_user=posix_getpwuid(Settings::Get('system.vmail_uid'));
+$vmail_group=posix_getgrgid(Settings::Get('system.vmail_gid'));
 
 /* If one of them are not set, call it 'vmail' and suggest creating user/group
  * in scripts. */
@@ -34,121 +34,121 @@ if ($vmail_group === false) {
 	$vmail_groupname=$vmail_group['name'];
 }
 
-return Array(
-	'debian_squeeze' => Array(
-		'label' => 'Debian 6.0 (Squeeze)',
-		'services' => Array(
-			'http' => Array(
+return array(
+	'debian_squeeze' => array(
+		'label' => 'Debian 6.0 (Squeeze) [deprecated]',
+		'services' => array(
+			'http' => array(
 				'label' => $lng['admin']['configfiles']['http'],
-				'daemons' => Array(
-					'apache2' => Array(
+				'daemons' => array(
+					'apache2' => array(
 						'label' => 'Apache 2',
-						'commands' => Array(
-							'mkdir -p ' . $settings['system']['documentroot_prefix'],
-							'mkdir -p ' . $settings['system']['logfiles_directory'],
-							($settings['system']['deactivateddocroot'] != '') ? 'mkdir -p ' . $settings['system']['deactivateddocroot'] : '',
-							'mkdir -p ' . $settings['system']['mod_fcgid_tmpdir'],
-							'chmod 1777 ' . $settings['system']['mod_fcgid_tmpdir'],
+						'commands' => array(
+							'mkdir -p ' . Settings::Get('system.documentroot_prefix'),
+							'mkdir -p ' . Settings::Get('system.logfiles_directory'),
+							(Settings::Get('system.deactivateddocroot') != '') ? 'mkdir -p ' . Settings::Get('system.deactivateddocroot') : '',
+							'mkdir -p ' . Settings::Get('system.mod_fcgid_tmpdir'),
+							'chmod 1777 ' . Settings::Get('system.mod_fcgid_tmpdir'),
 							'a2dismod userdir'
 						),
-						'files' => ((int)$settings['phpfpm']['enabled'] == 1) ?
-							Array(
-								'etc_apache2_mods-enabled_fastcgi.conf' => '/etc/apache2/mods-enabled/fastcgi.conf'
-							)
-							:
-							null,
-						'restart' => Array(
+						'files' => ((int)Settings::Get('phpfpm.enabled') == 1) ?
+						array(
+							'etc_apache2_mods-enabled_fastcgi.conf' => '/etc/apache2/mods-enabled/fastcgi.conf'
+						)
+						:
+						null,
+						'restart' => array(
 							'/etc/init.d/apache2 restart'
 						),
 					),
-					'lighttpd' => Array(
+					'lighttpd' => array(
 						'label' => 'Lighttpd Webserver',
-						'commands_1' => Array(
+						'commands_1' => array(
 							'apt-get install lighttpd',
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_lighttpd.conf' => '/etc/lighttpd/lighttpd.conf',
 						),
-						'commands_2' => Array(
+						'commands_2' => array(
 							$configcommand['vhost'],
 							$configcommand['diroptions'],
 							$configcommand['v_inclighty'],
 							$configcommand['d_inclighty'],
 							'lighty-disable-mod cgi',
 							'lighty-disable-mod fastcgi',
-							'mkdir -p ' . $settings['system']['documentroot_prefix'],
-							'mkdir -p ' . $settings['system']['logfiles_directory'],
-							($settings['system']['deactivateddocroot'] != '') ? 'mkdir -p ' . $settings['system']['deactivateddocroot'] : '',
-							'mkdir -p ' . $settings['system']['mod_fcgid_tmpdir'],
-							'chmod 1777 ' . $settings['system']['mod_fcgid_tmpdir']
+							'mkdir -p ' . Settings::Get('system.documentroot_prefix'),
+							'mkdir -p ' . Settings::Get('system.logfiles_directory'),
+							(Settings::Get('system.deactivateddocroot') != '') ? 'mkdir -p ' . Settings::Get('system.deactivateddocroot') : '',
+							'mkdir -p ' . Settings::Get('system.mod_fcgid_tmpdir'),
+							'chmod 1777 ' . Settings::Get('system.mod_fcgid_tmpdir')
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/lighttpd restart'
 						)
 					),
-					'nginx' => Array(
+					'nginx' => array(
 						'label' => 'Nginx Webserver',
-						'commands_1' => Array(
+						'commands_1' => array(
 							'apt-get install nginx php5-cgi',
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_nginx_nginx.conf' => '/etc/nginx/nginx.conf',
 							'etc_init.d_php-fcgi' => '/etc/init.d/php-fcgi'
 						),
-						'commands_2' => Array(
+						'commands_2' => array(
 							'rm /etc/nginx/sites-enabled/default',
-							'mkdir -p ' . $settings['system']['documentroot_prefix'],
-							'mkdir -p ' . $settings['system']['logfiles_directory'],
-							//'mkdir -p ' . $settings['system']['deactivateddocroot'],
-							'mkdir -p ' . $settings['system']['mod_fcgid_tmpdir'],
-							'chmod 1777 ' . $settings['system']['mod_fcgid_tmpdir'],
+							'mkdir -p ' . Settings::Get('system.documentroot_prefix'),
+							'mkdir -p ' . Settings::Get('system.logfiles_directory'),
+							(Settings::Get('system.deactivateddocroot') != '') ? 'mkdir -p ' . Settings::Get('system.deactivateddocroot') : '',
+							'mkdir -p ' . Settings::Get('system.mod_fcgid_tmpdir'),
+							'chmod 1777 ' . Settings::Get('system.mod_fcgid_tmpdir'),
 							'chmod u+x /etc/init.d/php-fcgi'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/php-fcgi start',
 							'/etc/init.d/nginx restart'
 						)
 					)
 				)
 			),
-			'dns' => Array(
+			'dns' => array(
 				'label' => $lng['admin']['configfiles']['dns'],
-				'daemons' => Array(
-					'bind' => Array(
+				'daemons' => array(
+					'bind' => array(
 						'label' => 'Bind9',
-						'commands' => Array(
+						'commands' => array(
 							'apt-get install bind9',
-							'echo "include \"' . $settings['system']['bindconf_directory'] . 'froxlor_bind.conf\";" >> /etc/bind/named.conf',
-							'touch ' . $settings['system']['bindconf_directory'] . 'froxlor_bind.conf',
-							'chown root:bind ' . $settings['system']['bindconf_directory'] . 'froxlor_bind.conf',
-							'chmod 0644 ' . $settings['system']['bindconf_directory'] . 'froxlor_bind.conf'
+							'echo "include \"' . Settings::Get('system.bindconf_directory') . 'froxlor_bind.conf\";" >> /etc/bind/named.conf',
+							'touch ' . Settings::Get('system.bindconf_directory') . 'froxlor_bind.conf',
+							'chown root:bind ' . Settings::Get('system.bindconf_directory') . 'froxlor_bind.conf',
+							'chmod 0644 ' . Settings::Get('system.bindconf_directory') . 'froxlor_bind.conf'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/bind9 restart'
 						)
 					),
-					'powerdns' => Array(
+					'powerdns' => array(
 						'label' => 'PowerDNS',
-						'files' => Array(
+						'files' => array(
 							'etc_powerdns_pdns.conf' => '/etc/powerdns/pdns.conf',
 							'etc_powerdns_pdns-froxlor.conf' => '/etc/powerdns/pdns_froxlor.conf',
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/pdns restart'
 						)
 					),
 				)
 			),
-			'smtp' => Array(
+			'smtp' => array(
 				'label' => $lng['admin']['configfiles']['smtp'],
-				'daemons' => Array(
-					'postfix_courier' => Array(
+				'daemons' => array(
+					'postfix_courier' => array(
 						'label' => 'Postfix/Courier',
-						'commands' => Array(
-							($vmail_group === false) ? 'groupadd -g ' . $settings['system']['vmail_gid'] . ' '.$vmail_groupname : '',
-							($vmail_user === false) ? 'useradd -u ' . $settings['system']['vmail_uid'] . ' -g ' . $vmail_groupname . ' ' . $vmail_username : '',
-							'mkdir -p ' . $settings['system']['vmail_homedir'],
-							'chown -R '.$vmail_username.':'.$vmail_groupname.' ' . $settings['system']['vmail_homedir'],
+						'commands' => array(
+							($vmail_group === false) ? 'groupadd -g ' . Settings::Get('system.vmail_gid') . ' '.$vmail_groupname : '',
+							($vmail_user === false) ? 'useradd -u ' . Settings::Get('system.vmail_uid') . ' -g ' . $vmail_groupname . ' ' . $vmail_username : '',
+							'mkdir -p ' . Settings::Get('system.vmail_homedir'),
+							'chown -R '.$vmail_username.':'.$vmail_groupname.' ' . Settings::Get('system.vmail_homedir'),
 							'apt-get install postfix postfix-mysql libsasl2-2 libsasl2-modules libsasl2-modules-sql',
 							'mkdir -p /var/spool/postfix/etc/pam.d',
 							'mkdir -p /var/spool/postfix/var/run/mysqld',
@@ -170,7 +170,7 @@ return Array(
 							'chmod 0640 /etc/postfix/mysql-virtual_sender_permissions.cf',
 							'chmod 0600 /etc/postfix/sasl/smtpd.conf',
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_postfix_main.cf' => '/etc/postfix/main.cf',
 							'etc_postfix_mysql-virtual_alias_maps.cf' => '/etc/postfix/mysql-virtual_alias_maps.cf',
 							'etc_postfix_mysql-virtual_mailbox_domains.cf' => '/etc/postfix/mysql-virtual_mailbox_domains.cf',
@@ -178,38 +178,38 @@ return Array(
 							'etc_postfix_mysql-virtual_sender_permissions.cf' => '/etc/postfix/mysql-virtual_sender_permissions.cf',
 							'etc_postfix_sasl_smtpd.conf' => '/etc/postfix/sasl/smtpd.conf'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'newaliases',
 							'/etc/init.d/postfix restart'
 						)
 					),
-					'dkim' => Array(
+					'dkim' => array(
 						'label' => 'DomainKey filter',
-						'commands_1' => Array(
+						'commands_1' => array(
 							'apt-get install dkim-filter',
 							'mkdir -p /etc/postfix/dkim'
 						),
-						'files' => Array(
+						'files' => array(
 							'dkim-filter.conf' => '/etc/dkim-filter.conf'
 						),
-						'commands_2' => Array(
+						'commands_2' => array(
 							'echo "milter_default_action = accept" >> /etc/postfix/main.cf',
 							'echo "milter_protocol = 2" >> /etc/postfix/main.cf',
 							'echo "smtpd_milters = inet:localhost:8891" >> /etc/postfix/main.cf',
 							'echo "non_smtpd_milters = inet:localhost:8891" >> /etc/postfix/main.cf'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/dkim-filter restart',
 							'/etc/init.d/postfix restart'
 						)
 					),
-					'postfix_dovecot' => Array(
+					'postfix_dovecot' => array(
 						'label' => 'Postfix/Dovecot',
-						'commands' => Array(
-							($vmail_group === false) ? 'groupadd -g ' . $settings['system']['vmail_gid'] . ' ' . $vmail_groupname : '',
-							($vmail_user === false) ? 'useradd -u ' . $settings['system']['vmail_uid'] . ' -g ' . $vmail_groupname . ' ' . $vmail_username : '',
-							'mkdir -p ' . $settings['system']['vmail_homedir'],
-							'chown -R ' . $vmail_username . ':' . $vmail_groupname . ' ' . $settings['system']['vmail_homedir'],
+						'commands' => array(
+							($vmail_group === false) ? 'groupadd -g ' . Settings::Get('system.vmail_gid') . ' ' . $vmail_groupname : '',
+							($vmail_user === false) ? 'useradd -u ' . Settings::Get('system.vmail_uid') . ' -g ' . $vmail_groupname . ' ' . $vmail_username : '',
+							'mkdir -p ' . Settings::Get('system.vmail_homedir'),
+							'chown -R ' . $vmail_username . ':' . $vmail_groupname . ' ' . Settings::Get('system.vmail_homedir'),
 							'apt-get install postfix postfix-mysql',
 							'mkdir -p /var/spool/postfix/etc/pam.d',
 							'mkdir -p /var/spool/postfix/var/run/mysqld',
@@ -230,7 +230,7 @@ return Array(
 							'chmod 0640 /etc/postfix/mysql-virtual_mailbox_maps.cf',
 							'chmod 0640 /etc/postfix/mysql-virtual_sender_permissions.cf'
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_postfix_main.cf' => '/etc/postfix/main.cf',
 							'etc_postfix_master.cf' => '/etc/postfix/master.cf',
 							'etc_postfix_mysql-virtual_alias_maps.cf' => '/etc/postfix/mysql-virtual_alias_maps.cf',
@@ -238,105 +238,105 @@ return Array(
 							'etc_postfix_mysql-virtual_mailbox_maps.cf' => '/etc/postfix/mysql-virtual_mailbox_maps.cf',
 							'etc_postfix_mysql-virtual_sender_permissions.cf' => '/etc/postfix/mysql-virtual_sender_permissions.cf'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/postfix restart',
 							'newaliases'
 						)
 					),
-					'postfix_mxaccess' => Array(
+					'postfix_mxaccess' => array(
 						'label' => 'Postfix MX-Access (anti spam)',
-						'files' => Array(
+						'files' => array(
 							'etc_postfix_mx_access' => '/etc/postfix/mx_access',
 							'etc_postfix_main.cf' => '/etc/postfix/main.cf'
 						),
-						'commands_1' => Array(
+						'commands_1' => array(
 							'postmap /etc/postfix/mx_access'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/postfix restart'
 						)
 					),
-					'exim4' => Array(
+					'exim4' => array(
 						'label' => 'Exim4',
-						'commands_1' => Array(
+						'commands_1' => array(
 							'dpkg-reconfigure exim4-config',
 							'# choose "no configuration at this time" and "splitted configuration files" in the dialog'
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_exim4_conf.d_acl_30_exim4-config_check_rcpt.rul' => '/etc/exim4/conf.d/acl/30_exim4-config_check_rcpt.rul',
 							'etc_exim4_conf.d_auth_30_froxlor-config' => '/etc/exim4/conf.d/auth/30_froxlor-config',
 							'etc_exim4_conf.d_main_10_froxlor-config_options' => '/etc/exim4/conf.d/main/10_froxlor-config_options',
 							'etc_exim4_conf.d_router_180_froxlor-config' => '/etc/exim4/conf.d/router/180_froxlor-config',
 							'etc_exim4_conf.d_transport_30_froxlor-config' => '/etc/exim4/conf.d/transport/30_froxlor-config'
 						),
-						'commands_2' => Array(
+						'commands_2' => array(
 							'chmod o-rx /var/lib/exim4',
 							'chmod o-rx /etc/exim4/conf.d/main/10_froxlor-config_options'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/exim4 restart'
 						)
 					)
 				)
 			),
-			'mail' => Array(
+			'mail' => array(
 				'label' => $lng['admin']['configfiles']['mail'],
-				'daemons' => Array(
-					'courier' => Array(
+				'daemons' => array(
+					'courier' => array(
 						'label' => 'Courier',
-						'commands' => Array(
+						'commands' => array(
 							'apt-get install courier-pop courier-imap courier-authlib-mysql'
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_courier_authdaemonrc' => '/etc/courier/authdaemonrc',
 							'etc_courier_authmysqlrc' => '/etc/courier/authmysqlrc'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/courier-authdaemon restart',
 							'/etc/init.d/courier-pop restart'
 						)
 					),
-					'dovecot' => Array(
+					'dovecot' => array(
 						'label' => 'Dovecot',
-						'commands_1' => Array(
+						'commands_1' => array(
 							'apt-get install dovecot-imapd dovecot-pop3d'
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_dovecot_dovecot.conf' => '/etc/dovecot/dovecot.conf',
 							'etc_dovecot_dovecot-sql.conf' => '/etc/dovecot/dovecot-sql.conf'
 						),
-						'commands_2' => Array(
+						'commands_2' => array(
 							'chmod 0640 /etc/dovecot/dovecot-sql.conf'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/dovecot restart'
 						)
 					)
 				)
 			),
-			'ftp' => Array(
+			'ftp' => array(
 				'label' => $lng['admin']['configfiles']['ftp'],
-				'daemons' => Array(
-					'proftpd' => Array(
+				'daemons' => array(
+					'proftpd' => array(
 						'label' => 'ProFTPd',
-						'commands' => Array(
+						'commands' => array(
 							'apt-get install proftpd-basic proftpd-mod-mysql'
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_proftpd_sql.conf' => '/etc/proftpd/sql.conf',
 							'etc_proftpd_modules.conf' => '/etc/proftpd/modules.conf',
 							'etc_proftpd_proftpd.conf' => '/etc/proftpd/proftpd.conf'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/proftpd restart'
 						)
 					),
-					'pure-ftpd' => Array(
+					'pure-ftpd' => array(
 						'label' => 'Pure FTPd',
-						'commands_1' => Array(
+						'commands_1' => array(
 							'apt-get install pure-ftpd-common pure-ftpd-mysql'
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_pure-ftpd_conf_MinUID' => '/etc/pure-ftpd/conf/MinUID',
 							'etc_pure-ftpd_conf_MySQLConfigFile' => '/etc/pure-ftpd/conf/MySQLConfigFile',
 							'etc_pure-ftpd_conf_NoAnonymous' => '/etc/pure-ftpd/conf/NoAnonymous',
@@ -348,50 +348,50 @@ return Array(
 							'etc_pure-ftpd_conf_Bind' => '/etc/pure-ftpd/conf/Bind',
 							'etc_default_pure-ftpd-common' => '/etc/default/pure-ftpd-common'
 						),
-						'commands_2' => Array(
+						'commands_2' => array(
 							'chmod 0640 /etc/pure-ftpd/db/mysql.conf'
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/pure-ftpd-mysql restart'
 						)
 					),
 				)
 			),
-			'etc' => Array(
+			'etc' => array(
 				'label' => $lng['admin']['configfiles']['etc'],
-				'daemons' => Array(
-					'cron' => Array(
+				'daemons' => array(
+					'cron' => array(
 						'label' => 'Crond (cronscript)',
-						'files' => Array(
+						'files' => array(
 							'etc_cron.d_froxlor' => '/etc/cron.d/froxlor'
 						),
-						'restart' => Array(
-							'/etc/init.d/cron restart'
+						'restart' => array(
+							Settings::Get('system.crondreload')
 						)
 					),
-					'awstats' => Array(
+					'awstats' => array(
 						'label' => 'Awstats',
-						'commands' => Array(
+						'commands' => array(
 							'apt-get install awstats',
-							'cp /usr/share/awstats/tools/awstats_buildstaticpages.pl '.makeCorrectDir($settings['system']['awstats_path']),
-							'mv '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.conf').' '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf'),
-							'sed -i.bak \'s/^DirData/# DirData/\' '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf'),
+							'cp /usr/share/awstats/tools/awstats_buildstaticpages.pl '.makeCorrectDir(Settings::Get('system.awstats_path')),
+							'mv '.makeCorrectFile(Settings::Get('system.awstats_conf').'/awstats.conf').' '.makeCorrectFile(Settings::Get('system.awstats_conf').'/awstats.model.conf'),
+							'sed -i.bak \'s/^DirData/# DirData/\' '.makeCorrectFile(Settings::Get('system.awstats_conf').'/awstats.model.conf'),
 							'# Please make sure you deactivate awstats own cronjob as Froxlor handles that itself',
 							'rm /etc/cron.d/awstats'
 						),
 					),
-					'libnss' => Array(
+					'libnss' => array(
 						'label' => 'libnss (system login with mysql)',
-						'commands' => Array(
+						'commands' => array(
 							'apt-get install libnss-mysql nscd',
 							'chmod 600 /etc/nss-mysql.conf /etc/nss-mysql-root.conf'
 						),
-						'files' => Array(
+						'files' => array(
 							'etc_nss-mysql.conf' => '/etc/nss-mysql.conf',
 							'etc_nss-mysql-root.conf' => '/etc/nss-mysql-root.conf',
 							'etc_nsswitch.conf' => '/etc/nsswitch.conf',
 						),
-						'restart' => Array(
+						'restart' => array(
 							'/etc/init.d/nscd restart'
 						)
 					),
