@@ -21,6 +21,7 @@
  * Checks whether it is a valid ip
  *
  * @return mixed 	ip address on success, standard_error on failure
+ * @deprecated use validate_ip2
  */
 function validate_ip($ip, $return_bool = false, $lng = 'invalidip') {
 
@@ -32,9 +33,37 @@ function validate_ip($ip, $return_bool = false, $lng = 'invalidip') {
 			return false;
 		} else {
 			standard_error($lng, $ip);
-			exit;
+			exit();
 		}
 	} else {
 		return $ip;
 	}
+
+}
+
+/**
+ * Checks whether it is a valid ip
+ *
+ * @return mixed 	ip address on success, false on failure
+ */
+function validate_ip2($ip, $return_bool = false, $lng = 'invalidip', $allow_localhost = false) {
+
+	if ((filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)
+			|| filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4))
+			&& filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_NO_RES_RANGE | FILTER_FLAG_NO_PRIV_RANGE)
+	) {
+		return $ip;
+	}
+
+	// special case where localhost ip is allowed (mysql-access-hosts for example)
+	if ($allow_localhost && $ip == '127.0.0.1') {
+		return $ip;
+	}
+
+	if ($return_bool) {
+		return false;
+	} else {
+		standard_error($lng, $ip);
+		exit();
+	}
 }
