@@ -51,29 +51,29 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 	if ($row['type'] == '1') {
 
 		// get configuration-I/O object
-		$configio = new ConfigIO($settings);
+		$configio = new ConfigIO();
 		// clean up old configs
 		$configio->cleanUp();
 
 		if (!isset($webserver)) {
-			if ($settings['system']['webserver'] == "apache2") {
+			if (Settings::Get('system.webserver') == "apache2") {
 				$websrv = 'apache';
-				if ($settings['system']['mod_fcgid'] == 1 || $settings['phpfpm']['enabled'] == 1) {
+				if (Settings::Get('system.mod_fcgid') == 1 || Settings::Get('phpfpm.enabled') == 1) {
 					$websrv .= '_fcgid';
 				}
-			} elseif ($settings['system']['webserver'] == "lighttpd") {
+			} elseif (Settings::Get('system.webserver') == "lighttpd") {
 				$websrv = 'lighttpd';
-				if ($settings['system']['mod_fcgid'] == 1 || $settings['phpfpm']['enabled'] == 1) {
+				if (Settings::Get('system.mod_fcgid') == 1 || Settings::Get('phpfpm.enabled') == 1) {
 					$websrv .= '_fcgid';
 				}
-			} elseif($settings['system']['webserver'] == "nginx") {
+			} elseif (Settings::Get('system.webserver') == "nginx") {
 				$websrv = 'nginx';
-				if ($settings['phpfpm']['enabled'] == 1) {
+				if (Settings::Get('phpfpm.enabled') == 1) {
 					$websrv .= '_phpfpm';
 				}
 			}
 
-			$webserver = new $websrv($cronlog, $debugHandler, $idna_convert, $settings);
+			$webserver = new $websrv($cronlog, $debugHandler, $idna_convert);
 		}
 
 		if (isset($webserver)) {
@@ -87,30 +87,41 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 			echo "Please check you Webserver settings\n";
 		}
 
-		/**
-		 * FIXME
-		 * as we might have a change from mod_php to fcgid/fpm or the other way around
-		 * we need to check customer directory permissions
-		 * -> 0.9.31
-		 */
+		// if we use php-fpm and have a local user for froxlor, we need to
+		// add the webserver-user to the local-group in order to allow the webserver
+		// to access the fpm-socket
+		if (Settings::Get('phpfpm.enabled') == 1 && function_exists("posix_getgrnam")) {
+			// get group info about the local-user's group (e.g. froxlorlocal)
+			$groupinfo = posix_getgrnam(Settings::Get('phpfpm.vhost_httpgroup'));
+			// check group members
+			if (isset($groupinfo['members'])
+				&& !in_array(Settings::Get('system.httpuser'), $groupinfo['members'])
+			) {
+				// webserver has no access, add it
+				if (isFreeBSD()) {
+					safe_exec('pw user mod '.escapeshellarg(Settings::Get('system.httpuser')).' -G '.escapeshellarg(Settings::Get('phpfpm.vhost_httpgroup')));
+				} else {
+					safe_exec('usermod -a -G ' . escapeshellarg(Settings::Get('phpfpm.vhost_httpgroup')).' '.escapeshellarg(Settings::Get('system.httpuser')));
+				}
+			}
+		}
 
 	}
 
 	/**
 	 * TYPE=2 MEANS TO CREATE A NEW HOME AND CHOWN
 	 */
-	elseif ($row['type'] == '2')
-	{
+	elseif ($row['type'] == '2') {
 		fwrite($debugHandler, '  cron_tasks: Task2 started - create new home' . "\n");
 		$cronlog->logAction(CRON_ACTION, LOG_INFO, 'Task2 started - create new home');
 
 		if (is_array($row['data'])) {
 			// define paths
-			$userhomedir = makeCorrectDir($settings['system']['documentroot_prefix'] . '/' . $row['data']['loginname'] . '/');
-			$usermaildir = makeCorrectDir($settings['system']['vmail_homedir'] . '/' . $row['data']['loginname'] . '/');
+			$userhomedir = makeCorrectDir(Settings::Get('system.documentroot_prefix') . '/' . $row['data']['loginname'] . '/');
+			$usermaildir = makeCorrectDir(Settings::Get('system.vmail_homedir') . '/' . $row['data']['loginname'] . '/');
 
 			// stats directory
-			if ($settings['system']['awstats_enabled'] == '1') {
+			if (Settings::Get('system.awstats_enabled') == '1') {
 				$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: mkdir -p ' . escapeshellarg($userhomedir . 'awstats'));
 				safe_exec('mkdir -p ' . escapeshellarg($userhomedir . 'awstats'));
 				// in case we changed from the other stats -> remove old
@@ -143,20 +154,28 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 
 			$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: chown -R ' . (int)$row['data']['uid'] . ':' . (int)$row['data']['gid'] . ' ' . escapeshellarg($userhomedir));
 			safe_exec('chown -R ' . (int)$row['data']['uid'] . ':' . (int)$row['data']['gid'] . ' ' . escapeshellarg($userhomedir));
-			$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: chown -R ' . (int)$settings['system']['vmail_uid'] . ':' . (int)$settings['system']['vmail_gid'] . ' ' . escapeshellarg($usermaildir));
-			safe_exec('chown -R ' . (int)$settings['system']['vmail_uid'] . ':' . (int)$settings['system']['vmail_gid'] . ' ' . escapeshellarg($usermaildir));
+			// don't allow others to access the directory (webserver will be the group via libnss-mysql)
+			if (Settings::Get('system.mod_fcgid') == 1 || Settings::Get('phpfpm.enabled') == 1) {
+				// fcgid or fpm
+				safe_exec('chmod 0750 ' . escapeshellarg($userhomedir));
+			} else {
+				// mod_php -> no libnss-mysql -> no webserver-user in group
+				safe_exec('chmod 0755 ' . escapeshellarg($userhomedir));
+			}
+			$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: chown -R ' . (int)Settings::Get('system.vmail_uid') . ':' . (int)Settings::Get('system.vmail_gid') . ' ' . escapeshellarg($usermaildir));
+			safe_exec('chown -R ' . (int)Settings::Get('system.vmail_uid') . ':' . (int)Settings::Get('system.vmail_gid') . ' ' . escapeshellarg($usermaildir));
 		}
 	}
 
 	/**
 	 * TYPE=4 MEANS THAT SOMETHING IN THE BIND CONFIG HAS CHANGED. REBUILD froxlor_bind.conf IF BIND IS ENABLED
 	 */
-	elseif ($row['type'] == '4' && (int)$settings['system']['bind_enable'] != 0) {
+	elseif ($row['type'] == '4' && (int)Settings::Get('system.bind_enable') != 0) {
 		if (!isset($nameserver)) {
-			$nameserver = new bind($cronlog, $debugHandler, $settings);
+			$nameserver = new bind($cronlog, $debugHandler);
 		}
 
-		if ($settings['dkim']['use_dkim'] == '1') {
+		if (Settings::Get('dkim.use_dkim') == '1') {
 			$nameserver->writeDKIMconfigs();
 		}
 
@@ -168,11 +187,9 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 	 */
 	elseif ($row['type'] == '5') {
 		$cronlog->logAction(CRON_ACTION, LOG_INFO, 'Creating new FTP-home');
-		// FIXME %_backup clause not necessary after backup-feature is being removed
 		$result_directories_stmt = Database::query("
 			SELECT `f`.`homedir`, `f`.`uid`, `f`.`gid`, `c`.`documentroot` AS `customerroot`
 			FROM `" . TABLE_FTP_USERS . "` `f` LEFT JOIN `" . TABLE_PANEL_CUSTOMERS . "` `c` USING (`customerid`)
-			WHERE `f`.`username` NOT LIKE '%_backup'
 		");
 
 		while ($directory = $result_directories_stmt->fetch(PDO::FETCH_ASSOC)) {
@@ -190,65 +207,54 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 		if (is_array($row['data'])) {
 			if (isset($row['data']['loginname'])) {
 				// remove homedir
-				$homedir = makeCorrectDir($settings['system']['documentroot_prefix'] . '/' . $row['data']['loginname']);
+				$homedir = makeCorrectDir(Settings::Get('system.documentroot_prefix') . '/' . $row['data']['loginname']);
 
 				if (file_exists($homedir)
 					&& $homedir != '/'
-					&& $homedir != $settings['system']['documentroot_prefix']
-					&& substr($homedir, 0, strlen($settings['system']['documentroot_prefix'])) == $settings['system']['documentroot_prefix']
+					&& $homedir != Settings::Get('system.documentroot_prefix')
+					&& substr($homedir, 0, strlen(Settings::Get('system.documentroot_prefix'))) == Settings::Get('system.documentroot_prefix')
 				) {
 					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($homedir));
 					safe_exec('rm -rf '.escapeshellarg($homedir));
 				}
-				
-				// remove backup dir
-				// FIXME remove when backup-feature has been removed
-				$backupdir = makeCorrectDir($settings['system']['backup_dir'] . $row['data']['loginname']);
 
-				if (file_exists($backupdir)
-					&& $backupdir != '/'
-					&& $backupdir != $settings['system']['backup_dir']
-					&& substr($backupdir, 0, strlen($settings['system']['backup_dir'])) == $settings['system']['backup_dir']
-				) {
-					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($backupdir));
-					safe_exec('rm -rf '.escapeshellarg($backupdir));
-				}
-				
 				// remove maildir
-				$maildir = makeCorrectDir($settings['system']['vmail_homedir'] . '/' . $row['data']['loginname']);
+				$maildir = makeCorrectDir(Settings::Get('system.vmail_homedir') . '/' . $row['data']['loginname']);
 
 				if (file_exists($maildir)
 					&& $maildir != '/'
-					&& $maildir != $settings['system']['vmail_homedir']
-					&& substr($maildir, 0, strlen($settings['system']['vmail_homedir'])) == $settings['system']['vmail_homedir']
+					&& $maildir != Settings::Get('system.vmail_homedir')
+					&& substr($maildir, 0, strlen(Settings::Get('system.vmail_homedir'))) == Settings::Get('system.vmail_homedir')
 					&& is_dir($maildir)
-					&& fileowner($maildir) == $settings['system']['vmail_uid']
-					&& filegroup($maildir) == $settings['system']['vmail_gid']
+					&& fileowner($maildir) == Settings::Get('system.vmail_uid')
+					&& filegroup($maildir) == Settings::Get('system.vmail_gid')
 				) {
 					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($maildir));
-					safe_exec('rm -rf '.escapeshellarg($maildir));
+					// mail-adress allows many special characters, see http://en.wikipedia.org/wiki/Email_address#Local_part
+					$return = false;
+					safe_exec('rm -rf '.escapeshellarg($maildir), $return, array('|', '&', '`', '$', '~', '?'));
 				}
 
 				// remove tmpdir if it exists
-				$tmpdir = makeCorrectDir($settings['system']['mod_fcgid_tmpdir'] . '/' . $row['data']['loginname'] . '/');
+				$tmpdir = makeCorrectDir(Settings::Get('system.mod_fcgid_tmpdir') . '/' . $row['data']['loginname'] . '/');
 
 				if (file_exists($tmpdir)
 					&& is_dir($tmpdir)
 					&& $tmpdir != "/"
-					&& $tmpdir != $settings['system']['mod_fcgid_tmpdir']
-					&& substr($tmpdir, 0, strlen($settings['system']['mod_fcgid_tmpdir'])) == $settings['system']['mod_fcgid_tmpdir']
+					&& $tmpdir != Settings::Get('system.mod_fcgid_tmpdir')
+					&& substr($tmpdir, 0, strlen(Settings::Get('system.mod_fcgid_tmpdir'))) == Settings::Get('system.mod_fcgid_tmpdir')
 				) {
-					 $cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($tmpdir));
-					 safe_exec('rm -rf '.escapeshellarg($tmpdir));
+					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($tmpdir));
+					safe_exec('rm -rf '.escapeshellarg($tmpdir));
 				}
 
 				// webserver logs
-				$logsdir = makeCorrectFile($settings['system']['logfiles_directory'].'/'.$row['data']['loginname']);
+				$logsdir = makeCorrectFile(Settings::Get('system.logfiles_directory').'/'.$row['data']['loginname']);
 
 				if (file_exists($logsdir)
 					&& $logsdir != '/'
-					&& $logsdir != makeCorrectDir($settings['system']['logfiles_directory'])
-					&& substr($logsdir, 0, strlen($settings['system']['logfiles_directory'])) == $settings['system']['logfiles_directory']
+					&& $logsdir != makeCorrectDir(Settings::Get('system.logfiles_directory'))
+					&& substr($logsdir, 0, strlen(Settings::Get('system.logfiles_directory'))) == Settings::Get('system.logfiles_directory')
 				) {
 					// build up wildcard for webX-{access,error}.log{*}
 					$logfiles .= '-*';
@@ -277,42 +283,46 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 				}
 				$email_user = substr($email_full,0,strrpos($email_full,"@"));
 				$email_domain = substr($email_full,strrpos($email_full,"@")+1);
-				$maildirname = trim($settings['system']['vmail_maildirname']);
+				$maildirname = trim(Settings::Get('system.vmail_maildirname'));
 				// Add trailing slash to Maildir if needed
 				$maildirpath = $maildirname;
 				if (!empty($maildirname) and substr($maildirname,-1) != "/") {
 					$maildirpath .= "/";
 				}
 
-				$maildir = makeCorrectDir($settings['system']['vmail_homedir'] .'/'. $row['data']['loginname'] .'/'. $email_domain .'/'. $email_user);
+				$maildir = makeCorrectDir(Settings::Get('system.vmail_homedir') .'/'. $row['data']['loginname'] .'/'. $email_domain .'/'. $email_user);
 
 				if ($maildir != '/'
 					&& !empty($maildir)
 					&& !empty($email_full)
-					&& $maildir != $settings['system']['vmail_homedir']
-					&& substr($maildir, 0, strlen($settings['system']['vmail_homedir'])) == $settings['system']['vmail_homedir']
+					&& $maildir != Settings::Get('system.vmail_homedir')
+					&& substr($maildir, 0, strlen(Settings::Get('system.vmail_homedir'))) == Settings::Get('system.vmail_homedir')
 					&& is_dir($maildir)
 					&& is_dir(makeCorrectDir($maildir.'/'.$maildirpath))
-					&& fileowner($maildir) == $settings['system']['vmail_uid']
-					&& filegroup($maildir) == $settings['system']['vmail_gid']
+					&& fileowner($maildir) == Settings::Get('system.vmail_uid')
+					&& filegroup($maildir) == Settings::Get('system.vmail_gid')
 				) {
 					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($maildir));
-					safe_exec('rm -rf '.escapeshellarg($maildir));
+					// mail-adress allows many special characters, see http://en.wikipedia.org/wiki/Email_address#Local_part
+					$return = false;
+					safe_exec('rm -rf '.escapeshellarg($maildir), $return, array('|', '&', '`', '$', '~', '?'));
 
 				} else {
 					// backward-compatibility for old folder-structure
-					$maildir_old = makeCorrectDir($settings['system']['vmail_homedir'] .'/'. $row['data']['loginname'] .'/'. $row['data']['email']);
+					$maildir_old = makeCorrectDir(Settings::Get('system.vmail_homedir') .'/'. $row['data']['loginname'] .'/'. $row['data']['email']);
 
 					if ($maildir_old != '/'
 						&& !empty($maildir_old)
-						&& $maildir_old != $settings['system']['vmail_homedir']
-						&& substr($maildir_old, 0, strlen($settings['system']['vmail_homedir'])) == $settings['system']['vmail_homedir']
+						&& $maildir_old != Settings::Get('system.vmail_homedir')
+						&& substr($maildir_old, 0, strlen(Settings::Get('system.vmail_homedir'))) == Settings::Get('system.vmail_homedir')
 						&& is_dir($maildir_old)
-						&& fileowner($maildir_old) == $settings['system']['vmail_uid']
-						&& filegroup($maildir_old) == $settings['system']['vmail_gid']
+						&& fileowner($maildir_old) == Settings::Get('system.vmail_uid')
+						&& filegroup($maildir_old) == Settings::Get('system.vmail_gid')
 					) {
 						$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($maildir_old));
-						safe_exec('rm -rf '.escapeshellarg($maildir_old));
+						// mail-adress allows many special characters, see http://en.wikipedia.org/wiki/Email_address#Local_part
+						$return = false;
+						safe_exec('rm -rf '.escapeshellarg($maildir_old), $return, array('|', '&', '`', '$', '~', '?'));
 					}
 				}
 			}
@@ -334,11 +344,11 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 			) {
 				// remove specific homedir
 				$ftphomedir = makeCorrectDir($row['data']['homedir']);
-				$customerdocroot = makeCorrectDir($settings['system']['documentroot_prefix'].'/'.$row['data']['loginname'].'/');
+				$customerdocroot = makeCorrectDir(Settings::Get('system.documentroot_prefix').'/'.$row['data']['loginname'].'/');
 
-				if(file_exists($ftphomedir)
+				if (file_exists($ftphomedir)
 					&& $ftphomedir != '/'
-					&& $ftphomedir != $settings['system']['documentroot_prefix']
+					&& $ftphomedir != Settings::Get('system.documentroot_prefix')
 					&& $ftphomedir != $customerdocroot
 				) {
 					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, 'Running: rm -rf ' . escapeshellarg($ftphomedir));
@@ -351,33 +361,44 @@ while ($row = $result_tasks_stmt->fetch(PDO::FETCH_ASSOC)) {
 	/**
 	 * TYPE=10 Set the filesystem - quota
 	 */
-	elseif ($row['type'] == '10' && (int)$settings['system']['diskquota_enabled'] != 0) {
+	elseif ($row['type'] == '10' && (int)Settings::Get('system.diskquota_enabled') != 0) {
 
 		fwrite($debugHandler, '  cron_tasks: Task10 started - setting filesystem quota' . "\n");
 		$cronlog->logAction(CRON_ACTION, LOG_INFO, 'Task10 started - setting filesystem quota');
 
 		$usedquota = getFilesystemQuota();
 
-		// Select all customers Froxlor knows about
-		$result_stmt = Database::query("SELECT `guid`, `loginname`, `diskspace` FROM `" . TABLE_PANEL_CUSTOMERS . "`;");
-		while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
-			// We do not want to set a quota for root by accident
-			if ($row['guid'] != 0) {
-				// The user has no quota in Froxlor, but on the filesystem
-				if (($row['diskspace'] == 0 || $row['diskspace'] == -1024) 
+		// Check whether we really have entries to check
+		if (is_array($usedquota) && count($usedquota) > 0) {
+			// Select all customers Froxlor knows about
+			$result_stmt = Database::query("SELECT `guid`, `loginname`, `diskspace` FROM `" . TABLE_PANEL_CUSTOMERS . "`;");
+			while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
+				// We do not want to set a quota for root by accident
+				if ($row['guid'] != 0) {
+					// The user has no quota in Froxlor, but on the filesystem
+					if (($row['diskspace'] == 0 || $row['diskspace'] == -1024)
 						&& $usedquota[$row['guid']]['block']['hard'] != 0
-				) {
-					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, "Disabling quota for " . $row['loginname']);
-					safe_exec($settings['system']['diskquota_quotatool_path'] . " -u " . $row['guid'] . " -bl 0 -q 0 " . escapeshellarg($settings['system']['diskquota_customer_partition']));
-				}
-				// The user quota in Froxlor is different than on the filesystem
-				elseif ($row['diskspace'] != $usedquota[$row['guid']]['block']['hard'] 
+					) {
+						$cronlog->logAction(CRON_ACTION, LOG_NOTICE, "Disabling quota for " . $row['loginname']);
+						if (isFreeBSD()) {
+							safe_exec(Settings::Get('system.diskquota_quotatool_path') . " -e " . escapeshellarg(Settings::Get('system.diskquota_customer_partition')) . ":0:0 " . $row['guid']);
+						} else {
+							safe_exec(Settings::Get('system.diskquota_quotatool_path') . " -u " . $row['guid'] . " -bl 0 -q 0 " . escapeshellarg(Settings::Get('system.diskquota_customer_partition')));
+						}
+					}
+					// The user quota in Froxlor is different than on the filesystem
+					elseif ($row['diskspace'] != $usedquota[$row['guid']]['block']['hard']
 						&& $row['diskspace'] != -1024
-				) {
-					$cronlog->logAction(CRON_ACTION, LOG_NOTICE, "Setting quota for " . $row['loginname'] . " from " . $usedquota[$row['guid']]['block']['hard'] . " to " . $row['diskspace']);
-					safe_exec($settings['system']['diskquota_quotatool_path'] . " -u " . $row['guid'] . " -bl " . $row['diskspace'] . " -q " . $row['diskspace'] . " " . escapeshellarg($settings['system']['diskquota_customer_partition']));
+					) {
+						$cronlog->logAction(CRON_ACTION, LOG_NOTICE, "Setting quota for " . $row['loginname'] . " from " . $usedquota[$row['guid']]['block']['hard'] . " to " . $row['diskspace']);
+						if (isFreeBSD()) {
+							safe_exec(Settings::Get('system.diskquota_quotatool_path') . " -e " . escapeshellarg(Settings::Get('system.diskquota_customer_partition')) . ":" . $row['diskspace'] . ":" . $row['diskspace'] . " " . $row['guid']);
+						} else {
+							safe_exec(Settings::Get('system.diskquota_quotatool_path') . " -u " . $row['guid'] . " -bl " . $row['diskspace'] . " -q " . $row['diskspace'] . " " . escapeshellarg(Settings::Get('system.diskquota_customer_partition')));
+						}
+					}
 				}
-			}
+			}	
 		}
 	}
 }
